@@ -3,7 +3,7 @@ package DateTime::Format::Strptime;
 use strict;
 use warnings;
 
-our $VERSION = '1.66';
+our $VERSION = '1.67';
 
 use Carp qw( carp croak );
 use DateTime 1.00;
@@ -333,7 +333,7 @@ sub _build_parser {
     }
 
     return {
-        regex  => qr/\A\s*$regex/,
+        regex  => qr/(?:\A\s|\b)*$regex/,
         fields => \@fields,
     };
 }
@@ -1041,7 +1041,7 @@ DateTime::Format::Strptime - Parse and format strp and strf time patterns
 
 =head1 VERSION
 
-version 1.66
+version 1.67
 
 =head1 SYNOPSIS
 
@@ -1401,12 +1401,22 @@ Rick Measham <rickm@cpan.org>
 
 =back
 
-=head1 CONTRIBUTOR
+=head1 CONTRIBUTORS
 
-=for stopwords D. Ilmari Mannsåker
+=for stopwords D. Ilmari Mannsåker key-amb
+
+=over 4
+
+=item *
 
 D. Ilmari Mannsåker <ilmari.mannsaker@net-a-porter.com>
 
+=item *
+
+key-amb <yasutake.kiyoshi@gmail.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENCE
 
 This software is Copyright (c) 2015 - 2016 by Dave Rolsky.
